(v0.7.4)=
### 0.7.4 {small}`10 July, 2020`

#### Concatenation overhaul {pr}`378` {smaller}`I Virshup`

- New function {func}`anndata.concat` for concatenating `AnnData` objects along either observations or variables
- New documentation section: {doc}`/concatenation`

#### Functionality

- AnnData object created from dataframes with sparse values will have sparse `.X` {pr}`395` {smaller}`I Virshup`

#### Bug fixes

- Fixed error from `AnnData.concatenate` by bumping minimum versions of numpy and pandas {issue}`385`
- Fixed colors being incorrectly changed when `AnnData` object was subset {pr}`388`
